@@ -1,5 +1,6 @@
 import random
 import string
+import asyncio
 
 def generate_tool_call_id() -> str:
     """
@@ -23,3 +24,6 @@ def get_sub_agent_id_from_oas_by_name(agent_name: str, oas: dict) -> str | None:
         (k.lstrip('/') for k in oas.get("paths", {}) if oas["paths"][k].get("get", {}).get("operationId") == agent_name),
         None
     )
+
+async def wait(seconds: int):
+    await asyncio.sleep(seconds)
\ No newline at end of file
